Whoosh |release| documentation
==============================

Whoosh was created by `Matt Chaput <mailto:matt@whoosh.ca>`_. You can view outstanding issues on the `Whoosh Trac <http://trac.whoosh.ca>`_ and get help on the `Whoosh mailing list <http://groups.google.com/group/whoosh>`_.

Contents
--------

.. toctree::
    :glob:
    :maxdepth: 1
    
    quickstart
    schema
    indexing
    searching
    analysis
    highlight
    keywords
    spelling
    api/api
    tech/index

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

